Struct mvhashmap::MVHashMap[][src]

pub struct MVHashMap<K, V> { /* fields omitted */ }

Implementations

Create the MVHashMap structure from a list of possible writes. Each element in the list indicates a key that could potentially be modified at its given version.

Returns the MVHashMap, and the maximum number of writes that can write to one single key.

Get the number of keys in the MVHashMap.

Write to key at version. Function will return an error if the write is not in the initial possible_writes list.

Skips writing to key at version if that entry hasn’t been assigned. Function will return an error if the write is not in the initial possible_writes list.

Skips writing to key at version. Function will return an error if the write is not in the initial possible_writes list. skip should only be invoked when key at version hasn’t been assigned.

Get the value of key at version. Returns Ok(val) if such key is already assigned by previous transactions. Returns Err(None) if version is smaller than the write of all previous versions. Returns Err(Some(version)) if such key is dependent on the version-th transaction.

Create the MVHashMap structure from a list of possible writes in parallel.