Type Definition mvhashmap::Version [−][src]
pub type Version = usize;Expand description
A structure that holds placeholders for each write to the database
pub type Version = usize;A structure that holds placeholders for each write to the database